==> trade-center-api-0.9.0.0-20170526.105152-2-sources.jar: cn/com/duiba/order/center/api/dto/AmbPayFailLogDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

public class AmbPayFailLogDto implements Serializable{
	
	public static final  String PayStatusSuccess ="success";
	public static final  String PayStatusFail ="fail";
	private static final long serialVersionUID = -8196167421383918543L;

	private Long id;

	private Long orderId;

	private String orderNum;
	
	private Long ambSubOrderId;
	
	private Long ambPaychannelOrderId;
	
	private String tradeNo;
	
	private String paychannelType;
	
	private Long payPrice;
	
	private String remark;
	
	private String status;

	private Date gmtCreate;

	private Date gmtModified;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getAmbSubOrderId() {
		return ambSubOrderId;
	}

	public void setAmbSubOrderId(Long ambSubOrderId) {
		this.ambSubOrderId = ambSubOrderId;
	}

	public Long getAmbPaychannelOrderId() {
		return ambPaychannelOrderId;
	}

	public void setAmbPaychannelOrderId(Long ambPaychannelOrderId) {
		this.ambPaychannelOrderId = ambPaychannelOrderId;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public String getPaychannelType() {
		return paychannelType;
	}

	public void setPaychannelType(String paychannelType) {
		this.paychannelType = paychannelType;
	}

	public Long getPayPrice() {
		return payPrice;
	}

	public void setPayPrice(Long payPrice) {
		this.payPrice = payPrice;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
}

==> trade-center-api-3.0.15-20251104.085039-8-sources.jar: cn/com/duiba/order/center/api/dto/AmbPayFailLogDto.java <==
package cn.com.duiba.order.center.api.dto;

import java.io.Serializable;
import java.util.Date;

/**
 * AmbPayFailLogDto
 */
public class AmbPayFailLogDto implements Serializable{
	
	public static final  String PayStatusSuccess ="success";
	public static final  String PayStatusFail ="fail";
	private static final long serialVersionUID = -8196167421383918543L;

	private Long id;

	private Long orderId;

	private String orderNum;
	
	private Long ambSubOrderId;
	
	private Long ambPaychannelOrderId;
	
	private String tradeNo;
	
	private String paychannelType;
	
	private Long payPrice;
	
	private String remark;
	
	private String status;

	private Date gmtCreate;

	private Date gmtModified;

	//主订单子订单号
	private Long ordersItemId;

	public Long getId() {
		return id;
	}

	public void setId(Long id) {
		this.id = id;
	}

	public Long getOrderId() {
		return orderId;
	}

	public void setOrderId(Long orderId) {
		this.orderId = orderId;
	}

	public String getOrderNum() {
		return orderNum;
	}

	public void setOrderNum(String orderNum) {
		this.orderNum = orderNum;
	}

	public Long getAmbSubOrderId() {
		return ambSubOrderId;
	}

	public void setAmbSubOrderId(Long ambSubOrderId) {
		this.ambSubOrderId = ambSubOrderId;
	}

	public Long getAmbPaychannelOrderId() {
		return ambPaychannelOrderId;
	}

	public void setAmbPaychannelOrderId(Long ambPaychannelOrderId) {
		this.ambPaychannelOrderId = ambPaychannelOrderId;
	}

	public String getTradeNo() {
		return tradeNo;
	}

	public void setTradeNo(String tradeNo) {
		this.tradeNo = tradeNo;
	}

	public String getPaychannelType() {
		return paychannelType;
	}

	public void setPaychannelType(String paychannelType) {
		this.paychannelType = paychannelType;
	}

	public Long getPayPrice() {
		return payPrice;
	}

	public void setPayPrice(Long payPrice) {
		this.payPrice = payPrice;
	}

	public String getRemark() {
		return remark;
	}

	public void setRemark(String remark) {
		this.remark = remark;
	}

	public String getStatus() {
		return status;
	}

	public void setStatus(String status) {
		this.status = status;
	}

	public Long getOrdersItemId() {
		return ordersItemId;
	}

	public void setOrdersItemId(Long ordersItemId) {
		this.ordersItemId = ordersItemId;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public Date getGmtModified() {
		return gmtModified;
	}

	public void setGmtModified(Date gmtModified) {
		this.gmtModified = gmtModified;
	}
}
